==> nextcloud-23.0.9.tgz: nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
    "Server to server sharing is not enabled on this server" : "Sprístupňovanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať združené zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať združené zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na združené zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať združené zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať združené sprístupnenia.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Zdieľanie %1$s zlyhalo, táto položka už je zdieľaná s užívateľom %2$s ",
    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
    "Federated shares require read permissions" : "Federované zdieľanie vyžaduje práva na čítanie",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %1$s s zlyhalo, nepodarilo sa nájsť %2$s, možno je server momentálne nedostupný alebo používa certifikát s vlastným podpisom.",
    "Could not find share" : "Nebolo možné nájsť sprístupnenie",
    "Federated sharing" : "Združené sprístupňovanie",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "\"%3$s\" ste dostali ako vzdialenú zdieľanú položku od %4$s (%1$s) (v mene %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "\"%3$s\" ste dostali ako vzdialený zdieľaný súbor od %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Federated Cloud Sharing" : "Sprístupnenie prostredníctvom Federated Cloud",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID, viac na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID",
    "Sharing" : "Sprístupnenie",
    "Federated file sharing" : "Združené sprístupňovanie súborov",
    "Provide federated file sharing across servers" : "Poskytnúť združené sprístupňovanie súborov naprieč servermi",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi užívateľlmi na tomto serveri ako aj používanie federovaného zdieľania.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
    "Allow users on this server to send shares to groups on other servers" : "Povoliť používateľom na tomto serveri odosielať zdieľania skupinám na iných serveroch",
    "Allow users on this server to receive group shares from other servers" : "Povoliť používateľom na tomto serveri prijímať zdieľania skupín z iných serverov",
    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára",
    "Federated Cloud" : "Združený Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor združeného cloudu v dialógovom okne zdieľania. Má to podobu person@cloud.example.com",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it so your friends can share files with you:" : "Zdieľajte to, aby mohli vaši priatelia zdieľať súbory s vami:",
    "Twitter" : "Twitter",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Adjust how people can share between servers." : "Nastavte ako môžu ľudia medzi sebou zdieľať servery."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-24.0.9.tgz: nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Invalid Federated Cloud ID" : "Neplatné združené Cloud ID",
    "Server to server sharing is not enabled on this server" : "Sprístupňovanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať združené zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať združené zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na združené zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať združené zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať združené sprístupnenia.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Zdieľanie %1$s zlyhalo, táto položka už je zdieľaná s užívateľom %2$s ",
    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
    "Federated shares require read permissions" : "Federované zdieľanie vyžaduje práva na čítanie",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %1$s s zlyhalo, nepodarilo sa nájsť %2$s, možno je server momentálne nedostupný alebo používa certifikát s vlastným podpisom.",
    "Could not find share" : "Nebolo možné nájsť sprístupnenie",
    "Federated sharing" : "Združené sprístupňovanie",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Federated Cloud Sharing" : "Sprístupnenie prostredníctvom Federated Cloud",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID, viac na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #Nextcloud Federated Cloud ID",
    "Sharing" : "Sprístupnenie",
    "Federated file sharing" : "Združené sprístupňovanie súborov",
    "Provide federated file sharing across servers" : "Poskytnúť združené sprístupňovanie súborov naprieč servermi",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi užívateľlmi na tomto serveri ako aj používanie federovaného zdieľania.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
    "Allow users on this server to send shares to groups on other servers" : "Povoliť používateľom na tomto serveri odosielať zdieľania skupinám na iných serveroch",
    "Allow users on this server to receive group shares from other servers" : "Povoliť používateľom na tomto serveri prijímať zdieľania skupín z iných serverov",
    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára",
    "Unable to update federated files sharing config" : "Nedá sa aktualizovať konfigurácia zdieľania federovaných súborov",
    "Federated Cloud" : "Združený Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor združeného cloudu v dialógovom okne zdieľania. Má to podobu person@cloud.example.com",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it so your friends can share files with you:" : "Zdieľajte to, aby mohli vaši priatelia zdieľať súbory s vami:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Zdieľajte so mnou prostredníctvom môjho #Nextcloud Federated Cloud ID, pozrite {url}",
    "Cloud ID copied to the clipboard" : "Cloud ID bol skopírovaný do schránky",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Clipboard is not available" : "Schránka nie je prístupná",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nie je podporované!",
    "Press ⌘-C to copy." : "Stlač ⌘-C pre skopírovanie.",
    "Press Ctrl-C to copy." : "Stlač Ctrl-C pre skopírovanie.",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "\"%3$s\" ste dostali ako vzdialenú zdieľanú položku od %4$s (%1$s) (v mene %5$s (%2$s))",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "\"%3$s\" ste dostali ako vzdialený zdieľaný súbor od %4$s (%1$s)",
    "Open documentation" : "Otvoriť dokumentáciu"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
